@@ -1,11 +1,11 @@
-# @(#)Ident: Unexpected.pm 2013-08-02 19:55 pjf ;
+# @(#)Ident: Unexpected.pm 2013-08-03 23:29 pjf ;
 
 package Unexpected;
 
 use 5.010001;
 use namespace::sweep;
 use overload '""' => 'as_string', fallback => 1;
-use version; our $VERSION = qv( sprintf '0.5.%d', q$Rev: 8 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.6.%d', q$Rev: 1 $ =~ /\d+/gmx );
 
 use Moo;
 use Scalar::Util      qw( blessed );
@@ -75,7 +75,7 @@ Unexpected - Exception class composed from traits
 
 =head1 Version
 
-This documents version v0.5.$Rev: 8 $ of L<Unexpected>
+This documents version v0.6.$Rev: 1 $ of L<Unexpected>
 
 =head1 Description
 
@@ -108,7 +108,8 @@ classes of error
 
 =head2 BUILDARGS
 
-Placeholder to shut L<Pod::Coverage> up
+Customizes the constructor. Accepts either a coderef, an object ref,
+a hashref, a scalar, or a list of key / value pairs
 
 =head2 BUILD
 
@@ -122,7 +123,8 @@ Class method which detects instances of this exception class
 
 =head1 Diagnostics
 
-None
+String overload is performed in this class as opposed to the stringify
+error role since overloading is not supported in L<Moo::Role>
 
 =head1 Dependencies
 
